@@ -12,7 +12,7 @@ import astropy.units as u
 from testreverseautoslitcode import find_shifts as fs
 from testreverseautoslitcode import refractioncorrection as ref
 from testreverseautoslitcode import astrometrycorrection as ac
-from testreverseautoslitcode import create_err_plot as cep
+from testreverseautoslitcode import create_err_plot
 from testreverseautoslitcode import write_ds9_file as w9f
 from testreverseautoslitcode import precessionroutine as pr
 from shutil import copyfile
@@ -245,7 +245,7 @@ def xytowcs(data_input_name,output_file):
 
     #create the error plot
     print('-----------------Creating Quick Look Plot---------------')
-    cep.create_err_plot(data,catalog_obj_ra,catalog_obj_dec,objects_ra,objects_dec,output_file)
+    create_err_plot(data,catalog_obj_ra,catalog_obj_dec,objects_ra,objects_dec,output_file)
     w9f.create_ds9_file(data,ra_shifted_centers,dec_shifted_centers,rot_angle,catalog_obj_ra,catalog_obj_dec,output_file)
 #=====================================================================================================================================
 #update the fits file extension to include the calculated center positions of the slits
