@@ -21,23 +21,17 @@ def create_ds9_file(data,ra_centers,dec_centers,theta,catalog_object_ra,catalog_
 #=================================================================================================================================
 #write out boxes to the reg_string
     reg_list ='icrs\nbox('+str_data['RA_Center'][0]+','+str_data['Dec_Center'][0]+','+width1+','+height1+','+pa+') # color=red'
-#    parser= DS9Parser(reg_string)
-#    regs = parser.shapes.to_regions()
-#    reg_list = regs
+
     i=4
     while i in range(1,int(len(str_data))):#-4):
         width = str(np.abs(np.max(data['X'][i:i+4])-np.min(data['X'][i:i+4]))/(0.7253 *0.99857*3600))
         height = str(np.abs(np.max(data['Y'][i:i+4])-np.min(data['Y'][i:i+4]))/(0.7253 *0.99857*3600))
-        reg_string='icrs\nbox('+str_data['RA_Center'][i]+','+str_data['Dec_Center'][i]+','+width+','+height+','+pa+') # color=red'
-        regs=reg_string
-#        parser= DS9Parser(reg_string)
-#        regs = parser.shapes.to_regions()
-        reg_list = reg_list + regs
+        reg_string='nbox('+str_data['RA_Center'][i]+','+str_data['Dec_Center'][i]+','+width+','+height+','+pa+') # color=red'
+        reg_list = reg_list + reg_string
         i = i+4
 #=================================================================================================================================
 
     #combine the two sections so the slits and vectors are both included
     reg_list = Regions.parse(reg_list,format='ds9')
-
     reg_filename = output_file+'.reg'
     reg_list.write(reg_filename,format='ds9',overwrite=True)
